@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import unittest
+from openstack.tests.unit import base
 
 from examples import connect
 from examples.image import create as image_create
@@ -18,16 +18,16 @@ from examples.image import delete as image_delete
 from examples.image import list as image_list
 
 
-class TestImage(unittest.TestCase):
+class TestImage(base.TestCase):
     """Test the image examples
 
     The purpose of these tests is to ensure the examples run without erring
     out.
     """
 
-    @classmethod
-    def setUpClass(cls):
-        cls.conn = connect.create_connection_from_config()
+    def setUp(self):
+        super(TestImage, self).setUp()
+        self.conn = connect.create_connection_from_config()
 
     def test_image(self):
         image_list.list_images(self.conn)
