@@ -10,12 +10,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.message import message_service
 
 
-class TestMessageService(testtools.TestCase):
+class TestMessageService(base.TestCase):
 
     def test_service(self):
         sot = message_service.MessageService()
@@ -24,5 +24,5 @@ class TestMessageService(testtools.TestCase):
         self.assertIsNone(sot.region)
         self.assertIsNone(sot.service_name)
         self.assertEqual(1, len(sot.valid_versions))
-        self.assertEqual('v1', sot.valid_versions[0].module)
-        self.assertEqual('v1', sot.valid_versions[0].path)
+        self.assertEqual('v2', sot.valid_versions[0].module)
+        self.assertEqual('v2', sot.valid_versions[0].path)
